/*
 * Vinyl widget example:
 * Name: From Now Date Formatter
 * Developer: Vinyl
 * Date: 6/21/2017
 */
define(function () {

    const install = function (holderElement, context) {
        const textNode = holderElement.childNodes[0];
        const cell = context.getCell();

        textNode.innerHTML = getValue(context, cell.value);

        cell.setChangeCallback('value', function (value) {
			// this is fired any time Vinyl changes the cell value,
			// can happen during editing
            textNode.innerHTML = getValue(context, value);
        });
    };

    const uninstall = function (holderElement, context) {
        // No implementation
    };

	/**
	 * Gets the value to output
	 */
    const getValue = function (context, value) {
		if (value === null) {
			// otherwise momentjs outputs the words "Invalid Date"
			return "";
		}

		// this is getting the actual momentJS library output
		// it was originally loaded by Vinyl
		const moment = context.loadedDependencies[0];

		// create the momentjs instance given a non null value
		const momentDate = moment(value);

		// used below to specify when "Now" is
		const fromDateValue = context.getParameter("FromDate");

		// hide the suffix "from now" or "ago" from the output
		const hideSuffix = context.getParameter("HideSuffix") == 'true';

		// if fromDate was passed in, use the from function of moment js
		// it allows you to specify when "now" is
		if (fromDateValue) {
			const fromDate = moment(fromDateValue);
			return momentDate.from(fromDate, hideSuffix);
		} else {
			return momentDate.fromNow(hideSuffix);
		}
	};

    return {
        callbacks: {
            events: {
                // adding and removing
                install: install,
                uninstall: uninstall
            }
        }
    };
});